@@ -77,7 +77,6 @@ func TestAddonsList(t *testing.T) {
 			Ambassador *interface{} `json:"ambassador"`
 		}
 
-		b := make([]byte, 590)
 		r, w, err := os.Pipe()
 		if err != nil {
 			t.Fatalf("failed to create pipe: %v", err)
@@ -93,12 +92,10 @@ func TestAddonsList(t *testing.T) {
 		if err := w.Close(); err != nil {
 			t.Fatalf("failed to close pipe: %v", err)
 		}
-		if _, err := r.Read(b); err != nil {
-			t.Fatalf("failed to read bytes: %v", err)
-		}
 		got := addons{}
-		if err := json.Unmarshal(b, &got); err != nil {
-			t.Fatalf("failed to unmarshal output; output: %q; err: %v", string(b), err)
+		dec := json.NewDecoder(r)
+		if err := dec.Decode(&got); err != nil {
+			t.Fatalf("failed to decode: %v", err)
 		}
 		if got.Ambassador == nil {
 			t.Errorf("expected `ambassador` field to not be nil, but was")
