@@ -19,7 +19,9 @@ package config
 import (
 	"github.com/spf13/cobra"
 	"k8s.io/minikube/pkg/addons"
+	"k8s.io/minikube/pkg/minikube/assets"
 	"k8s.io/minikube/pkg/minikube/exit"
+	"k8s.io/minikube/pkg/minikube/mustload"
 	"k8s.io/minikube/pkg/minikube/out"
 	"k8s.io/minikube/pkg/minikube/reason"
 	"k8s.io/minikube/pkg/minikube/style"
@@ -38,11 +40,18 @@ var addonsDisableCmd = &cobra.Command{
 		if addon == "heapster" {
 			exit.Message(reason.AddonUnsupported, "The heapster addon is depreciated. please try to disable metrics-server instead")
 		}
-		err := addons.SetAndSave(ClusterFlagValue(), addon, "false")
-		if err != nil {
-			exit.Error(reason.InternalAddonDisable, "disable failed", err)
+		_, cc := mustload.Partial(ClusterFlagValue())
+		validAddon, ok := assets.Addons[addon]
+		if !ok {
+			exit.Message(reason.AddonUnsupported, `"'{{.minikube_addon}}' is not a valid minikube addon`, out.V{"minikube_addon": addon})
 		}
-		out.Step(style.AddonDisable, `"The '{{.minikube_addon}}' addon is disabled`, out.V{"minikube_addon": addon})
+		if validAddon.IsEnabled(cc) {
+			err := addons.SetAndSave(ClusterFlagValue(), addon, "false")
+			if err != nil {
+				exit.Error(reason.InternalAddonDisable, "disable failed", err)
+			}
+		}
+		out.Styled(style.AddonDisable, `"The '{{.minikube_addon}}' addon is disabled`, out.V{"minikube_addon": addon})
 	},
 }
 
