@@ -302,7 +302,7 @@ docker-cli install instructions: https://minikube.sigs.k8s.io/docs/tutorials/doc
 			if err != nil {
 				exit.Message(reason.DrvPortForward, "Error getting port binding for '{{.driver_name}} driver: {{.error}}", out.V{"driver_name": driverName, "error": err})
 			}
-		} else if driver.IsQEMU(driverName) && pkgnetwork.IsUser(co.Config.Network) {
+		} else if driver.IsQEMU(driverName) && pkgnetwork.IsBuiltinQEMU(co.Config.Network) {
 			port = d.(*qemu.Driver).EnginePort
 		}
 
@@ -436,7 +436,7 @@ func dockerSetScript(ec DockerEnvConfig, w io.Writer) error {
 			exit.Message(reason.InternalOutputUsage, "error: --output must be 'text', 'yaml' or 'json'")
 		}
 	}
-	return shell.SetScript(ec.EnvConfig, w, dockerSetEnvTmpl, dockerShellCfgSet(ec, envVars))
+	return shell.SetScript(w, dockerSetEnvTmpl, dockerShellCfgSet(ec, envVars))
 }
 
 // dockerSetScript writes out a shell-compatible 'docker-env unset' script
