@@ -147,7 +147,7 @@ func platform() string {
 }
 
 // runStart handles the executes the flow of "minikube start"
-func runStart(cmd *cobra.Command, args []string) {
+func runStart(cmd *cobra.Command, _ []string) {
 	register.SetEventLogPath(localpath.EventLog(ClusterFlagValue()))
 	ctx := context.Background()
 	out.SetJSON(outputFormat == "json")
@@ -250,11 +250,10 @@ func runStart(cmd *cobra.Command, args []string) {
 				starter, err = provisionWithDriver(cmd, ds, existing)
 				if err != nil {
 					continue
-				} else {
-					// Success!
-					success = true
-					break
 				}
+				// Success!
+				success = true
+				break
 			}
 			if !success {
 				exitGuestProvision(err)
@@ -262,7 +261,7 @@ func runStart(cmd *cobra.Command, args []string) {
 		}
 	}
 
-	validateBuiltImageVersion(starter.Runner)
+	validateBuiltImageVersion(starter.Runner, ds.Name)
 
 	if existing != nil && driver.IsKIC(existing.Driver) {
 		if viper.GetBool(createMount) {
@@ -390,7 +389,10 @@ func virtualBoxMacOS13PlusWarning(driverName string) {
 `, out.V{"driver": driver})
 }
 
-func validateBuiltImageVersion(r command.Runner) {
+func validateBuiltImageVersion(r command.Runner, driverName string) {
+	if driverName == driver.None {
+		return
+	}
 	res, err := r.RunCmd(exec.Command("cat", "/version.json"))
 	if err != nil {
 		klog.Warningf("Unable to open version.json: %s", err)
@@ -1398,15 +1400,14 @@ func getContainerRuntime(old *config.ClusterConfig) string {
 	}
 
 	if paramRuntime == constants.DefaultContainerRuntime {
-		k8sVersion := getKubernetesVersion(old)
-		paramRuntime = defaultRuntime(k8sVersion)
+		paramRuntime = defaultRuntime()
 	}
 
 	return paramRuntime
 }
 
 // defaultRuntime returns the default container runtime
-func defaultRuntime(k8sVersion string) string {
+func defaultRuntime() string {
 	// minikube default
 	return constants.Docker
 }
@@ -1832,7 +1833,7 @@ func validateBareMetal(drvName string) {
 
 	// default container runtime varies, starting with Kubernetes 1.24 - assume that only the default container runtime has been tested
 	rtime := viper.GetString(containerRuntime)
-	if rtime != constants.DefaultContainerRuntime && rtime != defaultRuntime(getKubernetesVersion(nil)) {
+	if rtime != constants.DefaultContainerRuntime && rtime != defaultRuntime() {
 		out.WarningT("Using the '{{.runtime}}' runtime with the 'none' driver is an untested configuration!", out.V{"runtime": rtime})
 	}
 
@@ -1843,6 +1844,12 @@ func validateBareMetal(drvName string) {
 			exit.Message(reason.GuestMissingConntrack, "Sorry, Kubernetes {{.k8sVersion}} requires conntrack to be installed in root's path", out.V{"k8sVersion": version.String()})
 		}
 	}
+	// crictl is required starting with Kubernetes 1.24, for all runtimes since the removal of dockershim
+	if version.GTE(semver.MustParse("1.24.0-alpha.0")) {
+		if _, err := exec.LookPath("crictl"); err != nil {
+			exit.Message(reason.GuestMissingConntrack, "Sorry, Kubernetes {{.k8sVersion}} requires crictl to be installed in root's path", out.V{"k8sVersion": version.String()})
+		}
+	}
 }
 
 func exitIfNotForced(r reason.Kind, message string, v ...out.V) {
