@@ -220,6 +220,6 @@ func (e *execRunner) Remove(f assets.CopyableFile) error {
 	return os.Remove(dst)
 }
 
-func (e *execRunner) ReadableFile(sourcePath string) (assets.ReadableFile, error) {
+func (e *execRunner) ReadableFile(_ string) (assets.ReadableFile, error) {
 	return nil, fmt.Errorf("execRunner does not support ReadableFile - you could be the first to add it")
 }
