@@ -18,6 +18,66 @@ package constants
 
 var (
 	KubeadmImages = map[string]map[string]string{
+		"v1.27.0-rc.0": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.7-0",
+			"pause":           "3.9",
+		},
+		"v1.27.0-beta.0": {
+			"coredns/coredns": "v1.10.1",
+			"etcd":            "3.5.7-0",
+			"pause":           "3.9",
+		},
+		"v1.26.3": {
+			"coredns/coredns": "v1.9.3",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.9",
+		},
+		"v1.25.8": {
+			"coredns/coredns": "v1.9.3",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.8",
+		},
+		"v1.24.12": {
+			"coredns/coredns": "v1.8.6",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.7",
+		},
+		"v1.27.0-alpha.3": {
+			"coredns/coredns": "v1.10.0",
+			"etcd":            "3.5.7-0",
+			"pause":           "3.9",
+		},
+		"v1.26.2": {
+			"coredns/coredns": "v1.9.3",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.9",
+		},
+		"v1.25.7": {
+			"coredns/coredns": "v1.9.3",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.8",
+		},
+		"v1.24.11": {
+			"coredns/coredns": "v1.8.6",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.7",
+		},
+		"v1.23.17": {
+			"coredns/coredns": "v1.8.6",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.6",
+		},
+		"v1.27.0-alpha.2": {
+			"coredns/coredns": "v1.10.0",
+			"etcd":            "3.5.7-0",
+			"pause":           "3.9",
+		},
+		"v1.27.0-alpha.1": {
+			"coredns/coredns": "v1.10.0",
+			"etcd":            "3.5.6-0",
+			"pause":           "3.9",
+		},
 		"v1.26.1": {
 			"coredns/coredns": "v1.9.3",
 			"etcd":            "3.5.6-0",
