@@ -69,6 +69,7 @@ func (e *ErrISOFeature) Error() string {
 type Docker struct {
 	Socket            string
 	Runner            CommandRunner
+	NetworkPlugin     string
 	ImageRepository   string
 	KubernetesVersion semver.Version
 	Init              sysinit.Manager
@@ -140,6 +141,9 @@ func (r *Docker) Enable(disOthers bool, cgroupDriver string, inUserNamespace boo
 	if err := populateCRIConfig(r.Runner, r.SocketPath()); err != nil {
 		return err
 	}
+	if err := generateCRIDockerdConfig(r.Runner, r.ImageRepository, r.KubernetesVersion, r.NetworkPlugin); err != nil {
+		return err
+	}
 
 	if err := r.Init.Unmask("docker.service"); err != nil {
 		return err
@@ -170,6 +174,9 @@ func (r *Docker) Enable(disOthers bool, cgroupDriver string, inUserNamespace boo
 		if err := r.Init.Restart(r.CRIService); err != nil {
 			return err
 		}
+		if err := r.Init.Restart("cri-docker"); err != nil {
+			return err
+		}
 	}
 
 	return nil
@@ -382,11 +389,13 @@ func (r *Docker) CGroupDriver() (string, error) {
 // KubeletOptions returns kubelet options for a runtime.
 func (r *Docker) KubeletOptions() map[string]string {
 	if r.UseCRI {
-		return map[string]string{
-			"container-runtime":          "remote",
-			"container-runtime-endpoint": r.SocketPath(),
-			"image-service-endpoint":     r.SocketPath(),
+		opts := map[string]string{
+			"container-runtime-endpoint": fmt.Sprintf("unix://%s", r.SocketPath()),
 		}
+		if r.KubernetesVersion.LT(semver.MustParse("1.24.0-alpha.0")) {
+			opts["container-runtime"] = "remote"
+		}
+		return opts
 	}
 	return map[string]string{
 		"container-runtime": "docker",
@@ -516,7 +525,7 @@ func (r *Docker) ContainerLogCmd(id string, len int, follow bool) string {
 
 // SystemLogCmd returns the command to retrieve system logs
 func (r *Docker) SystemLogCmd(len int) string {
-	return fmt.Sprintf("sudo journalctl -u docker -n %d", len)
+	return fmt.Sprintf("sudo journalctl -u docker -u cri-docker -n %d", len)
 }
 
 // setCGroup configures the docker daemon to use driver as cgroup manager
@@ -688,7 +697,17 @@ const (
 	CNICacheDir = "/var/lib/cni/cache"
 )
 
-func dockerConfigureNetworkPlugin(cr CommandRunner, networkPlugin string) error {
+func getCriDockerdPath(cr CommandRunner) string {
+	rr, err := cr.RunCmd(exec.Command("which", "cri-dockerd"))
+	if err != nil {
+		return "/usr/bin/cri-dockerd"
+	}
+	return strings.TrimSuffix(rr.Stdout.String(), "\n")
+}
+
+func generateCRIDockerdConfig(cr CommandRunner, imageRepository string, kv semver.Version, networkPlugin string) error {
+
+	pauseImage := images.Pause(kv, imageRepository)
 	// $ cri-dockerd --version
 	// cri-dockerd 0.2.6 (d8accf7)
 	// $ cri-dockerd --help | grep -i cni
@@ -702,9 +721,13 @@ func dockerConfigureNetworkPlugin(cr CommandRunner, networkPlugin string) error
 		networkPlugin = "cni"
 	}
 	opts := struct {
+		ExecPath       string
+		PauseImage     string
 		NetworkPlugin  string
 		ExtraArguments string
 	}{
+		ExecPath:       getCriDockerdPath(cr),
+		PauseImage:     pauseImage,
 		NetworkPlugin:  networkPlugin,
 		ExtraArguments: args,
 	}
@@ -712,7 +735,7 @@ func dockerConfigureNetworkPlugin(cr CommandRunner, networkPlugin string) error
 	const CRIDockerServiceConfFile = "/etc/systemd/system/cri-docker.service.d/10-cni.conf"
 	var CRIDockerServiceConfTemplate = template.Must(template.New("criDockerServiceConfTemplate").Parse(`[Service]
 ExecStart=
-ExecStart=/usr/bin/cri-dockerd --container-runtime-endpoint fd:// --network-plugin={{.NetworkPlugin}}{{.ExtraArguments}}`))
+ExecStart={{.ExecPath}} --container-runtime-endpoint fd:// --pod-infra-container-image={{.PauseImage}} --network-plugin={{.NetworkPlugin}}{{.ExtraArguments}}`))
 
 	b := bytes.Buffer{}
 	if err := CRIDockerServiceConfTemplate.Execute(&b, opts); err != nil {
