@@ -32,7 +32,7 @@ import (
 
 // DefaultKubeBinariesURL returns a URL to kube binaries
 func DefaultKubeBinariesURL() string {
-	return fmt.Sprintf("https://%s/kubernetes-release/release", downloadHost)
+	return fmt.Sprintf("https://%s%s/release", releaseHost, releasePath)
 }
 
 // binaryWithChecksumURL gets the location of a Kubernetes binary
@@ -55,7 +55,7 @@ func binaryWithChecksumURL(binaryName, version, osName, archName, binaryURL stri
 
 // Binary will download a binary onto the host
 func Binary(binary, version, osName, archName, binaryURL string) (string, error) {
-	targetDir := localpath.MakeMiniPath("cache", osName, version)
+	targetDir := localpath.MakeMiniPath("cache", osName, archName, version)
 	targetFilepath := path.Join(targetDir, binary)
 	targetLock := targetFilepath + ".lock"
 
