@@ -25,6 +25,7 @@ import (
 	"encoding/json"
 	"fmt"
 	"io"
+	"net"
 	"net/http"
 	"net/url"
 	"os"
@@ -44,6 +45,7 @@ import (
 	"k8s.io/minikube/pkg/minikube/detect"
 	"k8s.io/minikube/pkg/minikube/localpath"
 	"k8s.io/minikube/pkg/minikube/reason"
+	"k8s.io/minikube/pkg/minikube/service"
 	"k8s.io/minikube/pkg/util/retry"
 
 	"github.com/blang/semver/v4"
@@ -276,7 +278,7 @@ func runImageList(ctx context.Context, t *testing.T, profile, testName, format,
 
 func expectedImageFormat(format string) []string {
 	return []string{
-		fmt.Sprintf(format, "k8s.gcr.io/pause"),
+		fmt.Sprintf(format, "registry.k8s.io/pause"),
 		fmt.Sprintf(format, "registry.k8s.io/kube-apiserver"),
 	}
 }
@@ -621,7 +623,7 @@ func validateStartWithCustomCerts(ctx context.Context, t *testing.T, profile str
 }
 
 // validateAuditAfterStart makes sure the audit log contains the correct logging after minikube start
-func validateAuditAfterStart(ctx context.Context, t *testing.T, profile string) {
+func validateAuditAfterStart(_ context.Context, t *testing.T, profile string) {
 	// docs: Read the audit log file and make sure it contains the current minikube profile name
 	got, err := auditContains(profile)
 	if err != nil {
@@ -1038,7 +1040,7 @@ func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 
 		// docs: Run `minikube cache add` and make sure we can add a remote image to the cache
 		t.Run("add_remote", func(t *testing.T) {
-			for _, img := range []string{"k8s.gcr.io/pause:3.1", "k8s.gcr.io/pause:3.3", "k8s.gcr.io/pause:latest"} {
+			for _, img := range []string{"registry.k8s.io/pause:3.1", "registry.k8s.io/pause:3.3", "registry.k8s.io/pause:latest"} {
 				rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "cache", "add", img))
 				if err != nil {
 					t.Errorf("failed to 'cache add' remote image %q. args %q err %v", img, rr.Command(), err)
@@ -1091,10 +1093,10 @@ func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 		})
 
 		// docs: Run `minikube cache delete` and make sure we can delete an image from the cache
-		t.Run("delete_k8s.gcr.io/pause:3.3", func(t *testing.T) {
-			rr, err := Run(t, exec.CommandContext(ctx, Target(), "cache", "delete", "k8s.gcr.io/pause:3.3"))
+		t.Run("CacheDelete", func(t *testing.T) {
+			rr, err := Run(t, exec.CommandContext(ctx, Target(), "cache", "delete", "registry.k8s.io/pause:3.3"))
 			if err != nil {
-				t.Errorf("failed to delete image k8s.gcr.io/pause:3.3 from cache. args %q: %v", rr.Command(), err)
+				t.Errorf("failed to delete image registry.k8s.io/pause:3.3 from cache. args %q: %v", rr.Command(), err)
 			}
 		})
 
@@ -1104,11 +1106,11 @@ func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 			if err != nil {
 				t.Errorf("failed to do cache list. args %q: %v", rr.Command(), err)
 			}
-			if !strings.Contains(rr.Output(), "k8s.gcr.io/pause") {
-				t.Errorf("expected 'cache list' output to include 'k8s.gcr.io/pause' but got: ***%s***", rr.Output())
+			if !strings.Contains(rr.Output(), "registry.k8s.io/pause") {
+				t.Errorf("expected 'cache list' output to include 'registry.k8s.io/pause' but got: ***%s***", rr.Output())
 			}
-			if strings.Contains(rr.Output(), "k8s.gcr.io/pause:3.3") {
-				t.Errorf("expected 'cache list' output not to include k8s.gcr.io/pause:3.3 but got: ***%s***", rr.Output())
+			if strings.Contains(rr.Output(), "registry.k8s.io/pause:3.3") {
+				t.Errorf("expected 'cache list' output not to include registry.k8s.io/pause:3.3 but got: ***%s***", rr.Output())
 			}
 		})
 
@@ -1126,7 +1128,7 @@ func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 
 		// docs: Delete an image from minikube node and run `minikube cache reload` to make sure the image is brought back correctly
 		t.Run("cache_reload", func(t *testing.T) { // deleting image inside minikube node manually and expecting reload to bring it back
-			img := "k8s.gcr.io/pause:latest"
+			img := "registry.k8s.io/pause:latest"
 			// deleting image inside minikube node manually
 
 			var binary string
@@ -1161,7 +1163,7 @@ func validateCacheCmd(ctx context.Context, t *testing.T, profile string) {
 
 		// delete will clean up the cached images since they are global and all other tests will load it for no reason
 		t.Run("delete", func(t *testing.T) {
-			for _, img := range []string{"k8s.gcr.io/pause:3.1", "k8s.gcr.io/pause:latest"} {
+			for _, img := range []string{"registry.k8s.io/pause:3.1", "registry.k8s.io/pause:latest"} {
 				rr, err := Run(t, exec.CommandContext(ctx, Target(), "cache", "delete", img))
 				if err != nil {
 					t.Errorf("failed to delete %s from cache. args %q: %v", img, rr.Command(), err)
@@ -1385,14 +1387,6 @@ func validateProfileCmd(ctx context.Context, t *testing.T, profile string) {
 	})
 }
 
-func killContext(cmdContext *exec.Cmd, killDelay time.Duration, t *testing.T) {
-	time.Sleep(killDelay)
-	err := cmdContext.Process.Signal(os.Interrupt)
-	if err != nil {
-		t.Error("Failed to sent interrupt to proc", err)
-	}
-}
-
 // validateServiceCmd asserts basic "service" command functionality
 func validateServiceCmd(ctx context.Context, t *testing.T, profile string) {
 	defer PostMortemLogs(t, profile)
@@ -1423,101 +1417,175 @@ func validateServiceCmd(ctx context.Context, t *testing.T, profile string) {
 		}
 	}()
 
-	var rr *RunResult
-	var err error
-	// docs: Create a new `k8s.gcr.io/echoserver` deployment
-	// k8s.gcr.io/echoserver is not multi-arch
-	if arm64Platform() {
-		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node", "--image=k8s.gcr.io/echoserver-arm:1.8"))
-	} else {
-		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node", "--image=k8s.gcr.io/echoserver:1.8"))
-	}
+	validateServiceCmdDeployApp(ctx, t, profile)
+	validateServiceCmdList(ctx, t, profile)
+	validateServiceCmdJSON(ctx, t, profile)
+	validateServiceCmdHTTPS(ctx, t, profile)
+	validateServiceCmdFormat(ctx, t, profile)
+	validateServiceCmdURL(ctx, t, profile)
+}
 
-	if err != nil {
-		t.Fatalf("failed to create hello-node deployment with this command %q: %v.", rr.Command(), err)
-	}
-	rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "expose", "deployment", "hello-node", "--type=NodePort", "--port=8080"))
-	if err != nil {
-		t.Fatalf("failed to expose hello-node deployment: %q : %v", rr.Command(), err)
-	}
-
-	if _, err := PodWait(ctx, t, profile, "default", "app=hello-node", Minutes(10)); err != nil {
-		t.Fatalf("failed waiting for hello-node pod: %v", err)
-	}
-
-	// docs: Run `minikube service list` to make sure the newly created service is correctly listed in the output
-	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "service", "list"))
-	if err != nil {
-		t.Errorf("failed to do service list. args %q : %v", rr.Command(), err)
-	}
-	if !strings.Contains(rr.Stdout.String(), "hello-node") {
-		t.Errorf("expected 'service list' to contain *hello-node* but got -%q-", rr.Stdout.String())
-	}
-
-	// docs: Run `minikube service` with `--https --url` to make sure the HTTPS endpoint URL of the service is printed
-	cmdContext := exec.CommandContext(ctx, Target(), "-p", profile, "service", "--namespace=default", "--https", "--url", "hello-node")
-	if NeedsPortForward() {
-		go killContext(cmdContext, 2*time.Second, t)
-	}
-
-	rr, err = Run(t, cmdContext)
-	if err != nil && !strings.Contains(err.Error(), "interrupt") {
-		t.Fatalf("failed to get service url. args %q : %v", rr.Command(), err)
-	}
-
-	splits := strings.Split(rr.Stdout.String(), "|")
-	var endpoint string
-	// get the last endpoint in the output to test http to https
-	for _, v := range splits {
-		if strings.Contains(v, "http") {
-			endpoint = strings.TrimSpace(v)
+// validateServiceCmdDeployApp Create a new `registry.k8s.io/echoserver` deployment
+func validateServiceCmdDeployApp(ctx context.Context, t *testing.T, profile string) {
+	t.Run("DeployApp", func(t *testing.T) {
+		var rr *RunResult
+		var err error
+		// registry.k8s.io/echoserver is not multi-arch
+		if arm64Platform() {
+			rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node", "--image=registry.k8s.io/echoserver-arm:1.8"))
+		} else {
+			rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node", "--image=registry.k8s.io/echoserver:1.8"))
 		}
-	}
-	t.Logf("found endpoint: %s", endpoint)
 
-	u, err := url.Parse(endpoint)
-	if err != nil {
-		t.Fatalf("failed to parse service url endpoint %q: %v", endpoint, err)
-	}
-	if u.Scheme != "https" {
-		t.Errorf("expected scheme for %s to be 'https' but got %q", endpoint, u.Scheme)
-	}
+		if err != nil {
+			t.Fatalf("failed to create hello-node deployment with this command %q: %v.", rr.Command(), err)
+		}
+		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "expose", "deployment", "hello-node", "--type=NodePort", "--port=8080"))
+		if err != nil {
+			t.Fatalf("failed to expose hello-node deployment: %q : %v", rr.Command(), err)
+		}
 
-	cmdContext = exec.CommandContext(ctx, Target(), "-p", profile, "service", "hello-node", "--url", "--format={{.IP}}")
-	if NeedsPortForward() {
-		go killContext(cmdContext, 2*time.Second, t)
-	}
-	// docs: Run `minikube service` with `--url --format={{.IP}}` to make sure the IP address of the service is printed
-	rr, err = Run(t, cmdContext)
-	if err != nil && !strings.Contains(err.Error(), "interrupt") {
-		t.Errorf("failed to get service url with custom format. args %q: %v", rr.Command(), err)
-	}
+		if _, err := PodWait(ctx, t, profile, "default", "app=hello-node", Minutes(10)); err != nil {
+			t.Fatalf("failed waiting for hello-node pod: %v", err)
+		}
+	})
+}
 
-	if strings.TrimSpace(rr.Stdout.String()) != u.Hostname() {
-		t.Errorf("expected 'service --format={{.IP}}' output to be -%q- but got *%q* . args %q.", u.Hostname(), rr.Stdout.String(), rr.Command())
-	}
+// validateServiceCmdList Run `minikube service list` to make sure the newly created service is correctly listed in the output
+func validateServiceCmdList(ctx context.Context, t *testing.T, profile string) {
+	t.Run("List", func(t *testing.T) {
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "service", "list"))
+		if err != nil {
+			t.Errorf("failed to do service list. args %q : %v", rr.Command(), err)
+		}
+		if !strings.Contains(rr.Stdout.String(), "hello-node") {
+			t.Errorf("expected 'service list' to contain *hello-node* but got -%q-", rr.Stdout.String())
+		}
+	})
+}
 
-	cmdContext = exec.CommandContext(ctx, Target(), "-p", profile, "service", "hello-node", "--url")
-	if NeedsPortForward() {
-		go killContext(cmdContext, 2*time.Second, t)
-	}
-	// docs: Run `minikube service` with a regular `--url` to make sure the HTTP endpoint URL of the service is printed
-	rr, err = Run(t, cmdContext)
-	if err != nil {
-		t.Errorf("failed to get service url. args: %q: %v", rr.Command(), err)
-	}
+// validateServiceCmdJSON Run `minikube service list -o JSON` and make sure the services are correctly listed as JSON output
+func validateServiceCmdJSON(ctx context.Context, t *testing.T, profile string) {
+	t.Run("JSONOutput", func(t *testing.T) {
+		targetSvcName := "hello-node"
+		// helper function to run command then, return target service object from json output.
+		extractServiceObjFunc := func(rr *RunResult) *service.SvcURL {
+			var jsonObjects service.URLs
+			if err := json.Unmarshal(rr.Stdout.Bytes(), &jsonObjects); err != nil {
+				t.Fatalf("failed to decode json from profile list: args %q: %v", rr.Command(), err)
+			}
 
-	endpoint = strings.TrimSpace(rr.Stdout.String())
-	t.Logf("found endpoint for hello-node: %s", endpoint)
+			for _, svc := range jsonObjects {
+				if svc.Name == targetSvcName {
+					return &svc
+				}
+			}
+			return nil
+		}
 
-	u, err = url.Parse(endpoint)
-	if err != nil {
-		t.Fatalf("failed to parse %q: %v", endpoint, err)
-	}
+		start := time.Now()
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "service", "list", "-o", "json"))
+		if err != nil {
+			t.Fatalf("failed to list services with json format. args %q: %v", rr.Command(), err)
+		}
+		elapsed := time.Since(start)
+		t.Logf("Took %q to run %q", elapsed, rr.Command())
 
-	if u.Scheme != "http" {
-		t.Fatalf("expected scheme to be -%q- got scheme: *%q*", "http", u.Scheme)
+		pr := extractServiceObjFunc(rr)
+		if pr == nil {
+			t.Errorf("expected the json of 'service list' to include %q but got *%q*. args: %q", targetSvcName, rr.Stdout.String(), rr.Command())
+		}
+	})
+}
+
+// validateServiceCmdHTTPS Run `minikube service` with `--https --url` to make sure the HTTPS endpoint URL of the service is printed
+func validateServiceCmdHTTPS(ctx context.Context, t *testing.T, profile string) {
+	t.Run("HTTPS", func(t *testing.T) {
+		cmdCtx, cancel := context.WithTimeout(ctx, 15*time.Second)
+		defer cancel()
+		cmd := exec.CommandContext(cmdCtx, Target(), "-p", profile, "service", "--namespace=default", "--https", "--url", "hello-node")
+		rr, err := Run(t, cmd)
+		if isUnexpectedServiceError(cmdCtx, err) {
+			t.Fatalf("failed to get service url. args %q : %v", rr.Command(), err)
+		}
+
+		splits := strings.Split(rr.Stdout.String(), "|")
+		var endpoint string
+		// get the last endpoint in the output to test http to https
+		for _, v := range splits {
+			if strings.Contains(v, "http") {
+				endpoint = strings.TrimSpace(v)
+			}
+		}
+		t.Logf("found endpoint: %s", endpoint)
+
+		u, err := url.Parse(endpoint)
+		if err != nil {
+			t.Fatalf("failed to parse service url endpoint %q: %v", endpoint, err)
+		}
+		if u.Scheme != "https" {
+			t.Errorf("expected scheme for %s to be 'https' but got %q", endpoint, u.Scheme)
+		}
+	})
+}
+
+// validateServiceCmdFormat Run `minikube service` with `--url --format={{.IP}}` to make sure the IP address of the service is printed
+func validateServiceCmdFormat(ctx context.Context, t *testing.T, profile string) {
+	t.Run("Format", func(t *testing.T) {
+		cmdCtx, cancel := context.WithTimeout(ctx, 15*time.Second)
+		defer cancel()
+		cmd := exec.CommandContext(cmdCtx, Target(), "-p", profile, "service", "hello-node", "--url", "--format={{.IP}}")
+		rr, err := Run(t, cmd)
+		if isUnexpectedServiceError(cmdCtx, err) {
+			t.Errorf("failed to get service url with custom format. args %q: %v", rr.Command(), err)
+		}
+
+		stringIP := strings.TrimSpace(rr.Stdout.String())
+
+		if ip := net.ParseIP(stringIP); ip == nil {
+			t.Fatalf("%q is not a valid IP", stringIP)
+		}
+	})
+}
+
+// validateServiceCmdURL Run `minikube service` with a regular `--url` to make sure the HTTP endpoint URL of the service is printed
+func validateServiceCmdURL(ctx context.Context, t *testing.T, profile string) {
+	t.Run("URL", func(t *testing.T) {
+		cmdCtx, cancel := context.WithTimeout(ctx, 15*time.Second)
+		defer cancel()
+		cmd := exec.CommandContext(cmdCtx, Target(), "-p", profile, "service", "hello-node", "--url")
+		rr, err := Run(t, cmd)
+		if isUnexpectedServiceError(cmdCtx, err) {
+			t.Errorf("failed to get service url. args: %q: %v", rr.Command(), err)
+		}
+
+		endpoint := strings.TrimSpace(rr.Stdout.String())
+		t.Logf("found endpoint for hello-node: %s", endpoint)
+
+		u, err := url.Parse(endpoint)
+		if err != nil {
+			t.Fatalf("failed to parse %q: %v", endpoint, err)
+		}
+
+		if u.Scheme != "http" {
+			t.Fatalf("expected scheme to be -%q- got scheme: *%q*", "http", u.Scheme)
+		}
+	})
+}
+
+// isUnexpectedServiceError is used to prevent failing ServiceCmd tests on Docker Desktop due to DeadlineExceeded errors.
+// Due to networking constraints Docker Desktop requires creating an SSH tunnel to connect to a service. This command has
+// to be left running to keep the SSH tunnel connected, so for the ServiceCmd tests we set a timeout context so we can
+// check the output and then the command is terminated, otherwise it would keep runnning forever. So if using Docker
+// Desktop and the DeadlineExceeded, consider it an expected error.
+func isUnexpectedServiceError(ctx context.Context, err error) bool {
+	if err == nil {
+		return false
 	}
+	if !NeedsPortForward() {
+		return true
+	}
+	return ctx.Err() != context.DeadlineExceeded
 }
 
 func validateServiceCmdConnect(ctx context.Context, t *testing.T, profile string) {
@@ -1551,12 +1619,12 @@ func validateServiceCmdConnect(ctx context.Context, t *testing.T, profile string
 
 	var rr *RunResult
 	var err error
-	// docs: Create a new `k8s.gcr.io/echoserver` deployment
-	// k8s.gcr.io/echoserver is not multi-arch
+	// docs: Create a new `registry.k8s.io/echoserver` deployment
+	// registry.k8s.io/echoserver is not multi-arch
 	if arm64Platform() {
-		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node-connect", "--image=k8s.gcr.io/echoserver-arm:1.8"))
+		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node-connect", "--image=registry.k8s.io/echoserver-arm:1.8"))
 	} else {
-		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node-connect", "--image=k8s.gcr.io/echoserver:1.8"))
+		rr, err = Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "create", "deployment", "hello-node-connect", "--image=registry.k8s.io/echoserver:1.8"))
 	}
 
 	if err != nil {
@@ -1777,7 +1845,7 @@ func localEmptyCertPath() string {
 }
 
 // Copy extra file into minikube home folder for file sync test
-func setupFileSync(ctx context.Context, t *testing.T, profile string) {
+func setupFileSync(_ context.Context, t *testing.T, _ string) {
 	p := localSyncTestPath()
 	t.Logf("local sync path: %s", p)
 	syncFile := filepath.Join(*testdataDir, "sync.test")
