@@ -38,6 +38,7 @@ import (
 	"k8s.io/minikube/pkg/kapi"
 	"k8s.io/minikube/pkg/minikube/config"
 	"k8s.io/minikube/pkg/minikube/detect"
+	"k8s.io/minikube/pkg/minikube/reason"
 	"k8s.io/minikube/pkg/util"
 	"k8s.io/minikube/pkg/util/retry"
 )
@@ -61,6 +62,7 @@ func validateTunnelCmd(ctx context.Context, t *testing.T, profile string) {
 			name      string
 			validator validateFunc
 		}{
+			{"RunSecondTunnel", validateNoSecondTunnel},            // Ensure no two tunnels run simultaneously
 			{"StartTunnel", validateTunnelStart},                   // Start tunnel
 			{"WaitService", validateServiceStable},                 // Wait for service is stable
 			{"AccessDirect", validateAccessDirect},                 // Access test for loadbalancer IP
@@ -131,6 +133,69 @@ func validateTunnelStart(ctx context.Context, t *testing.T, profile string) {
 	tunnelSession = *ss
 }
 
+// validateNoSecondTunnel ensures only 1 tunnel can run simultaneously
+func validateNoSecondTunnel(ctx context.Context, t *testing.T, profile string) {
+	checkRoutePassword(t)
+
+	type SessInfo struct {
+		Stdout   string
+		Stderr   string
+		ExitCode int
+	}
+
+	sessCh := make(chan SessInfo)
+	sessions := make([]*StartSession, 2)
+
+	var runTunnel = func(idx int) {
+		args := []string{"-p", profile, "tunnel", "--alsologtostderr"}
+
+		ctx2, cancel := context.WithTimeout(ctx, Seconds(15))
+		defer cancel()
+		session, err := Start(t, exec.CommandContext(ctx2, Target(), args...))
+		if err != nil {
+			t.Errorf("failed to start tunnel: %v", err)
+		}
+		sessions[idx] = session
+
+		stderr, err := io.ReadAll(session.Stderr)
+		if err != nil {
+			t.Logf("Failed to read stderr: %v", err)
+		}
+		stdout, err := io.ReadAll(session.Stdout)
+		if err != nil {
+			t.Logf("Failed to read stdout: %v", err)
+		}
+
+		exitCode := 0
+		err = session.cmd.Wait()
+		if err != nil {
+			if exErr, ok := err.(*exec.ExitError); !ok {
+				t.Logf("failed to coerce exit error: %v", err)
+				exitCode = -1
+			} else {
+				exitCode = exErr.ExitCode()
+			}
+		}
+
+		sessCh <- SessInfo{Stdout: string(stdout), Stderr: string(stderr), ExitCode: exitCode}
+	}
+
+	// One of the two processes must fail to acquire lock and die. This should be the first process to die.
+	go runTunnel(0)
+	go runTunnel(1)
+
+	sessInfo := <-sessCh
+
+	if sessInfo.ExitCode != reason.SvcTunnelAlreadyRunning.ExitCode {
+		t.Errorf("tunnel command failed with unexpected error: exit code %d. stderr: %s\n stdout: %s", sessInfo.ExitCode, sessInfo.Stderr, sessInfo.Stdout)
+	}
+
+	for _, sess := range sessions {
+		sess.Stop(t)
+	}
+	<-sessCh
+}
+
 // validateServiceStable starts nginx pod, nginx service and waits nginx having loadbalancer ingress IP
 func validateServiceStable(ctx context.Context, t *testing.T, profile string) {
 	if detect.GithubActionRunner() && runtime.GOOS == "darwin" {
@@ -274,7 +339,7 @@ func validateDNSDig(ctx context.Context, t *testing.T, profile string) {
 
 // validateDNSDscacheutil validates if the DNS forwarding works by dscacheutil command DNS lookup
 // NOTE: DNS forwarding is experimental: https://minikube.sigs.k8s.io/docs/handbook/accessing/#dns-resolution-experimental
-func validateDNSDscacheutil(ctx context.Context, t *testing.T, profile string) {
+func validateDNSDscacheutil(ctx context.Context, t *testing.T, _ string) {
 	if detect.GithubActionRunner() && runtime.GOOS == "darwin" {
 		t.Skip("skipping: access direct test is broken on github actions on macos https://github.com/kubernetes/minikube/issues/8434")
 	}
@@ -299,7 +364,7 @@ func validateDNSDscacheutil(ctx context.Context, t *testing.T, profile string) {
 
 // validateAccessDNS validates if the test service can be accessed with DNS forwarding from host
 // NOTE: DNS forwarding is experimental: https://minikube.sigs.k8s.io/docs/handbook/accessing/#dns-resolution-experimental
-func validateAccessDNS(ctx context.Context, t *testing.T, profile string) {
+func validateAccessDNS(_ context.Context, t *testing.T, profile string) {
 	if detect.GithubActionRunner() && runtime.GOOS == "darwin" {
 		t.Skip("skipping: access direct test is broken on github actions on macos https://github.com/kubernetes/minikube/issues/8434")
 	}
@@ -363,7 +428,7 @@ func validateAccessDNS(ctx context.Context, t *testing.T, profile string) {
 }
 
 // validateTunnelDelete stops `minikube tunnel`
-func validateTunnelDelete(ctx context.Context, t *testing.T, profile string) {
+func validateTunnelDelete(_ context.Context, t *testing.T, _ string) {
 	checkRoutePassword(t)
 	// Stop tunnel
 	tunnelSession.Stop(t)
